@@ -8,7 +8,7 @@ package Net::Prometheus;
 use strict;
 use warnings;
 
-our $VERSION = '0.04';
+our $VERSION = '0.06';
 
 use Carp;
 
@@ -21,6 +21,8 @@ use Net::Prometheus::Histogram;
 
 use Net::Prometheus::ProcessCollector;
 
+use Net::Prometheus::Types qw( MetricSamples );
+
 =head1 NAME
 
 C<Net::Prometheus> - export monitoring metrics for F<prometheus>
@@ -143,7 +145,7 @@ sub unregister
 
    my $found;
    @{ $self->{collectors} } = grep {
-      not( $_ == $collector and $found++ )
+      not( $_ == $collector and ++$found )
    } @{ $self->{collectors} };
 
    $found or
@@ -257,6 +259,38 @@ sub new_metricgroup
    );
 }
 
+=head2 collect
+
+   @metricsamples = $prometheus->collect
+
+Returns a list of L<Net::Prometheus::Types/MetricSamples> obtained from all
+of the currently-registered collectors.
+
+=cut
+
+sub collect
+{
+   my $self = shift;
+
+   my $collectors = $self->{collectors};
+
+   my %samples_by_name;
+   foreach my $collector ( @{ $collectors } ) {
+      push @{ $samples_by_name{ $_->fullname } }, $_ for $collector->collect;
+   }
+
+   return map {
+      my @results = @{ $samples_by_name{ $_ } };
+      my $first = $results[0];
+
+      @results > 1 ?
+         MetricSamples( $first->fullname, $first->type, $first->help,
+            [ map { @{ $_->samples } } @results ]
+         ) :
+         $first;
+   } sort keys %samples_by_name;
+}
+
 =head2 render
 
    $str = $prometheus->render
@@ -291,8 +325,6 @@ sub render
 {
    my $self = shift;
 
-   my $collectors = $self->{collectors};
-
    return join "", map {
       my $metricsamples = $_;
 
@@ -307,7 +339,7 @@ sub render
             _render_labels( $sample->labels ),
             $sample->value
       } @{ $metricsamples->samples }
-   } map { $_->collect } @$collectors;
+   } $self->collect;
 }
 
 =head2 psgi_app
