@@ -9,7 +9,7 @@ use strict;
 use warnings;
 use base qw( Net::Prometheus::Metric );
 
-our $VERSION = '0.04';
+our $VERSION = '0.06';
 
 use Carp;
 use List::Util 1.33 qw( any );
@@ -85,7 +85,8 @@ sub new
 
 =head2 observe
 
-   $summary->observe( [ @label_values ], $value )
+   $summary->observe( @label_values, $value )
+   $summary->observe( \%labels, $value )
 
    $child->observe( $value )
 
